pub struct ModuleResolver { /* private fields */ }Expand description
Module resolver — maps dot-paths to files, detects circulars.
Implementations
Sourceimpl ModuleResolver
impl ModuleResolver
pub fn new(root: PathBuf) -> Self
pub fn set_current_file(&mut self, path: Option<PathBuf>)
pub fn root(&self) -> &Path
Sourcepub fn resolve_path(
&self,
segments: &[String],
) -> Result<ResolvedModule, TlError>
pub fn resolve_path( &self, segments: &[String], ) -> Result<ResolvedModule, TlError>
Resolve a dot-path (from use statement) to a file path.
Given segments like ["data", "transforms", "clean"]:
- Try
<base>/data/transforms/clean.tl(file module) - Try
<base>/data/transforms/clean/mod.tl(directory module) - Try
<base>/data/transforms.tlwith item “clean” (item within file) - Try
<base>/data/transforms/mod.tlwith item “clean” (item within dir module)
Sourcepub fn resolve_prefix(&self, segments: &[String]) -> Result<PathBuf, TlError>
pub fn resolve_prefix(&self, segments: &[String]) -> Result<PathBuf, TlError>
Resolve a prefix path for group/wildcard imports. Returns the file path for the module containing the group items.
Sourcepub fn begin_import(&mut self, path: &Path) -> Result<(), TlError>
pub fn begin_import(&mut self, path: &Path) -> Result<(), TlError>
Check for circular dependency. Returns Err if circular.
Sourcepub fn end_import(&mut self, path: &Path)
pub fn end_import(&mut self, path: &Path)
Mark import as complete.
Sourcepub fn get_cached(&self, path: &Path) -> Option<&ModuleExports>
pub fn get_cached(&self, path: &Path) -> Option<&ModuleExports>
Check if a module is cached.
Sourcepub fn cache_module(&mut self, path: &Path, exports: ModuleExports)
pub fn cache_module(&mut self, path: &Path, exports: ModuleExports)
Cache a module’s exports.
Sourcepub fn resolve_package_path(
&self,
segments: &[String],
package_roots: &HashMap<String, PathBuf>,
) -> Option<ResolvedModule>
pub fn resolve_package_path( &self, segments: &[String], package_roots: &HashMap<String, PathBuf>, ) -> Option<ResolvedModule>
Resolve a module path against package roots. Returns a ResolvedModule if the first segment matches a package name.